@@ -74,6 +74,7 @@ def _clean_bag_api_output(api_output: dict) -> List[dict]:
         "gebruiksdoelen",
         "typeAdresseerbaarObject",
         "woonplaatsNaam",
+        "postcode"
     ]
 
     items_to_rename = {
@@ -136,6 +137,7 @@ def get_zip_code_info(
         - oppervlakte
         - gebruiksdoelen
         - type_object
+        - postcode
     """
 
     # Get the response from the API
